@@ -335,6 +335,30 @@ class VariableOsInstallX11Composite(VideoVariable):
             state = None
         return composite or state or defaultComposite
 
+class VariableOsInstallFbResolutionPreferred(ResolutionVariable):
+    """
+    Framebuffer resolution
+    """
+    type = 'choiceedit'
+    opt = ['--fb']
+    metavalue = "<width>x<height>"
+    xorg_need = False
+    fbres = True
+    value = "auto"
+
+    def init(self):
+        self.help = _("set the framebuffer resolution")
+        self.label = _("Framebuffer resolution")
+
+    def choice(self):
+        yield ("auto", _("Auto"))
+        for i in ResolutionVariable.choice(self):
+            yield (i,i)
+
+    def check(self, value):
+        if value == "auto":
+            return
+        ResolutionVariable.check(self, value)
 
 class VariableOsInstallFbResolution(ResolutionVariable):
     """
@@ -360,6 +384,9 @@ class VariableOsInstallFbResolution(ResolutionVariable):
         return self.GetBool('install.os_install_uefi_set')
 
     def get(self):
+        custom = self.Get('os_install_fb_resolution_preferred')
+        if custom != "auto":
+            return custom
         x11res = self.Get('os_install_x11_resolution')
         if self.using_kms() or self.using_uefi():
             return x11res
